/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sl extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AUD" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BRL", "BRL" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "GBP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "NZD", "NZD" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TWD", "TWD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XCD", "XCD" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "andorska peseta" },
            { "aed", "dirham Zdru\u017eenih arabskih emiratov" },
            { "afa", "stari afganistanski afgani (1927\u20132002)" },
            { "afn", "afgani" },
            { "all", "albanski lek" },
            { "amd", "armenski dram" },
            { "ang", "nizozemsko-antilski gulden" },
            { "aoa", "angolska kvanza" },
            { "aok", "stara angolska kvanza (1977\u20131990)" },
            { "aon", "angolska nova kvanza (1990\u20132000)" },
            { "aor", "konvertibilna angolska kvanza (1995\u20131999)" },
            { "ara", "argentinski avstral" },
            { "arp", "argentinski peso (1983\u20131985)" },
            { "ars", "argentinski peso" },
            { "ats", "avstrijski \u0161iling" },
            { "aud", "avstralski dolar" },
            { "awg", "arubski florin" },
            { "azm", "stari azerbajd\u017eanski manat (1993\u20132006)" },
            { "azn", "azerbajd\u017eanski manat" },
            { "bad", "bosansko-hercegovski dinar" },
            { "bam", "bosansko-hercegovska konvertibilna marka" },
            { "bbd", "barbado\u0161ki dolar" },
            { "bdt", "banglade\u0161ka taka" },
            { "bec", "belgijski konvertibilni frank" },
            { "bef", "belgijski frank" },
            { "bel", "belgijski finan\u010dni frank" },
            { "bgl", "stari bolgarski lev" },
            { "bgn", "bolgarski lev" },
            { "bhd", "bahranski dinar" },
            { "bif", "burundski frank" },
            { "bmd", "bermudski dolar" },
            { "bnd", "brunejski dolar" },
            { "bob", "bolivijski boliviano" },
            { "bop", "bolivijski peso" },
            { "bov", "bolivijski mvdol" },
            { "brb", "brazilski novi kruzeiro (1967\u20131986)" },
            { "brc", "brazilski kruzado" },
            { "bre", "stari brazilski kruzeiro (1990\u20131993)" },
            { "brl", "brazilski real" },
            { "brn", "novi brazilski kruzado" },
            { "brr", "brazilski kruzeiro" },
            { "bsd", "bahamski dolar" },
            { "btn", "butanski ngultrum" },
            { "buk", "burmanski kjat" },
            { "bwp", "bocvanska pula" },
            { "byb", "beloruski novi rubelj (1994\u20131999)" },
            { "byn", "beloruski rubelj" },
            { "byr", "beloruski rubelj (2000\u20132016)" },
            { "bzd", "belizejski dolar" },
            { "cad", "kanadski dolar" },
            { "cdf", "kongo\u0161ki frank" },
            { "che", "evro WIR" },
            { "chf", "\u0161vicarski frank" },
            { "chw", "frank WIR" },
            { "clf", "\u010dilski unidades de fomento" },
            { "clp", "\u010dilski peso" },
            { "cnh", "kitajski juan (offshore)" },
            { "cny", "kitajski juan" },
            { "cop", "kolumbijski peso" },
            { "cou", "kolumbijska enota realne vrednosti" },
            { "crc", "kostari\u0161ki kolon" },
            { "csd", "stari srbski dinar" },
            { "csk", "\u010de\u0161koslova\u0161ka krona" },
            { "cuc", "kubanski konvertibilni peso" },
            { "cup", "kubanski peso" },
            { "cve", "zelenortski eskudo" },
            { "cyp", "ciprski funt" },
            { "czk", "\u010de\u0161ka krona" },
            { "ddm", "vzhodnonem\u0161ka marka" },
            { "dem", "nem\u0161ka marka" },
            { "djf", "d\u017eibutski frank" },
            { "dkk", "danska krona" },
            { "dop", "dominikanski peso" },
            { "dzd", "al\u017eirski dinar" },
            { "ecs", "ekvadorski sukre" },
            { "ecv", "ekvadorska enota realne vrednosti (UVC)" },
            { "eek", "estonska krona" },
            { "egp", "egiptovski funt" },
            { "ern", "eritrejska nakfa" },
            { "esa", "\u0161panska pezeta (ra\u010dun A)" },
            { "esb", "\u0161panska pezeta (ra\u010dun B)" },
            { "esp", "\u0161panska pezeta" },
            { "etb", "etiopski bir" },
            { "eur", "evro" },
            { "fim", "finska marka" },
            { "fjd", "fid\u017eijski dolar" },
            { "fkp", "falklandski funt" },
            { "frf", "francoski frank" },
            { "gbp", "britanski funt" },
            { "gek", "gruzijski bon lari" },
            { "gel", "gruzijski lari" },
            { "ghc", "stari ganski cedi (1979\u20132007)" },
            { "ghs", "ganski cedi" },
            { "gip", "gibraltarski funt" },
            { "gmd", "gambijski dalasi" },
            { "gnf", "gvinejski frank" },
            { "gns", "gvinejski sili" },
            { "gqe", "ekwele Ekvatorialne Gvineje" },
            { "grd", "gr\u0161ka drahma" },
            { "gtq", "gvatemalski kecal" },
            { "gwe", "eskudo Portugalske Gvineje" },
            { "gwp", "peso Gvineje Bissau" },
            { "gyd", "gvajanski dolar" },
            { "hkd", "hongkon\u0161ki dolar" },
            { "hnl", "hondura\u0161ka lempira" },
            { "hrd", "hrva\u0161ki dinar" },
            { "hrk", "hrva\u0161ka kuna" },
            { "htg", "haitski gurd" },
            { "huf", "mad\u017earski forint" },
            { "idr", "indonezijska rupija" },
            { "iep", "irski funt" },
            { "ilp", "izraelski funt" },
            { "ils", "izraelski \u0161ekel" },
            { "inr", "indijska rupija" },
            { "iqd", "ira\u0161ki dinar" },
            { "irr", "iranski rial" },
            { "isk", "islandska krona" },
            { "itl", "italijanska lira" },
            { "jmd", "jamaj\u0161ki dolar" },
            { "jod", "jordanski dinar" },
            { "jpy", "japonski jen" },
            { "kes", "kenijski \u0161iling" },
            { "kgs", "kirgi\u0161ki som" },
            { "khr", "kambo\u0161ki riel" },
            { "kmf", "komorski frank" },
            { "kpw", "severnokorejski von" },
            { "krw", "ju\u017enokorejski von" },
            { "kwd", "kuvajtski dinar" },
            { "kyd", "kajmanski dolar" },
            { "kzt", "kazahstanski tenge" },
            { "lak", "lao\u0161ki kip" },
            { "lbp", "libanonski funt" },
            { "lkr", "\u0161rilan\u0161ka rupija" },
            { "lrd", "liberijski dolar" },
            { "lsl", "leso\u0161ki loti" },
            { "ltl", "litovski litas" },
            { "ltt", "litvanski litas" },
            { "luc", "luksembur\u0161ki konvertibilni frank" },
            { "luf", "luksembur\u0161ki frank" },
            { "lul", "luksembur\u0161ki finan\u010dni frank" },
            { "lvl", "latvijski lats" },
            { "lvr", "latvijski rubelj" },
            { "lyd", "libijski dinar" },
            { "mad", "maro\u0161ki dirham" },
            { "maf", "maro\u0161ki frank" },
            { "mdl", "moldavijski leu" },
            { "mga", "malga\u0161ki ariarij" },
            { "mgf", "malga\u0161ki frank" },
            { "mkd", "makedonski denar" },
            { "mlf", "malijski frank" },
            { "mmk", "mjanmarski kjat" },
            { "mnt", "mongolski tugrik" },
            { "mop", "makavska pataka" },
            { "mro", "mavretanska uguija (1973\u20132017)" },
            { "mru", "mavretanska uguija" },
            { "mtl", "malte\u0161ka lira" },
            { "mtp", "malte\u0161ki funt" },
            { "mur", "mavricijska rupija" },
            { "mvr", "maldivska rufija" },
            { "mwk", "malavijska kva\u010da" },
            { "mxn", "mehi\u0161ki peso" },
            { "mxp", "mehi\u0161ki srebrni peso (1861\u20131992)" },
            { "mxv", "mehi\u0161ka inverzna enota (UDI)" },
            { "myr", "malezijski ringit" },
            { "mze", "mozambi\u0161ki eskudo" },
            { "mzm", "stari mozambi\u0161ki metikal" },
            { "mzn", "mozambi\u0161ki metikal" },
            { "nad", "namibijski dolar" },
            { "ngn", "nigerijska naira" },
            { "nic", "nikara\u0161ka kordova" },
            { "nio", "nikara\u0161ka zlata kordova" },
            { "nlg", "nizozemski gulden" },
            { "nok", "norve\u0161ka krona" },
            { "npr", "nepalska rupija" },
            { "nzd", "novozelandski dolar" },
            { "omr", "omanski rial" },
            { "pab", "panamska balboa" },
            { "pei", "perujski inti" },
            { "pen", "perujski sol" },
            { "pes", "perujski sol (1863\u20131965)" },
            { "pgk", "kina Papue Nove Gvineje" },
            { "php", "filipinski peso" },
            { "pkr", "pakistanska rupija" },
            { "pln", "poljski novi zlot" },
            { "plz", "stari poljski zlot (1950\u20131995)" },
            { "pte", "portugalski eskudo" },
            { "pyg", "paragvajski gvarani" },
            { "qar", "katarski rial" },
            { "rhd", "rodezijski dolar" },
            { "rol", "stari romunski leu" },
            { "ron", "romunski leu" },
            { "rsd", "srbski dinar" },
            { "rub", "ruski rubelj" },
            { "rur", "ruski rubelj (1991\u20131998)" },
            { "rwf", "ruandski frank" },
            { "sar", "saudski rial" },
            { "sbd", "solomonski dolar" },
            { "scr", "sej\u0161elska rupija" },
            { "sdd", "stari sudanski dinar" },
            { "sdg", "sudanski funt" },
            { "sdp", "stari sudanski funt" },
            { "sek", "\u0161vedska krona" },
            { "sgd", "singapurski dolar" },
            { "shp", "funt Sv. Helene" },
            { "sit", "slovenski tolar" },
            { "skk", "slova\u0161ka krona" },
            { "sll", "sieraleonski leone" },
            { "sos", "somalski \u0161iling" },
            { "srd", "surinamski dolar" },
            { "srg", "surinamski gulden" },
            { "ssp", "ju\u017enosudanski funt" },
            { "std", "saotomejska dobra (1977\u20132017)" },
            { "stn", "saotomejska dobra" },
            { "sur", "sovjetski rubelj" },
            { "svc", "salvadorski kolon" },
            { "syp", "sirijski funt" },
            { "szl", "svazijski lilangeni" },
            { "thb", "tajski baht" },
            { "tjr", "tad\u017eikistanski rubelj" },
            { "tjs", "tad\u017eikistanski somoni" },
            { "tmm", "turkmenski manat" },
            { "tmt", "turkmenistanski novi manat" },
            { "tnd", "tunizijski dinar" },
            { "top", "tongovska paanga" },
            { "tpe", "timorski eskudo" },
            { "trl", "stara tur\u0161ka lira" },
            { "try", "nova tur\u0161ka lira" },
            { "ttd", "dolar Trinidada in Tobaga" },
            { "twd", "novi tajvanski dolar" },
            { "tzs", "tanzanijski \u0161iling" },
            { "uah", "ukrajinska grivna" },
            { "uak", "ukrajinski karbovanci" },
            { "ugs", "stari ugandski \u0161iling (1966\u20131987)" },
            { "ugx", "ugandski \u0161iling" },
            { "usd", "ameri\u0161ki dolar" },
            { "usn", "ameri\u0161ki dolar, naslednji dan" },
            { "uss", "ameri\u0161ki dolar, isti dan" },
            { "uyp", "stari urugvajski peso (1975\u20131993)" },
            { "uyu", "urugvajski peso" },
            { "uzs", "uzbe\u0161ki sum" },
            { "veb", "venezuelski bolivar (1871\u20132008)" },
            { "vef", "venezuelski bolivar (2008\u20132018)" },
            { "ves", "venezuelski bolivar" },
            { "vnd", "vientnamski dong" },
            { "vuv", "vanuatujski vatu" },
            { "wst", "samoanska tala" },
            { "xaf", "CFA frank BEAC" },
            { "xag", "srebro" },
            { "xau", "zlato" },
            { "xba", "evropska sestavljena enota" },
            { "xbb", "evropska monetarna enota" },
            { "xbc", "evropska obra\u010dunska enota (XBC)" },
            { "xbd", "evropska obra\u010dunska enota (XBD)" },
            { "xcd", "vzhodnokaribski dolar" },
            { "xdr", "posebne pravice \u010drpanja" },
            { "xeu", "evropska denarna enota" },
            { "xfo", "zlati frank" },
            { "xfu", "frank UIC" },
            { "xof", "zahodnoafri\u0161ki frank CFA" },
            { "xpd", "paladij" },
            { "xpf", "CFP frank" },
            { "xpt", "platina" },
            { "xts", "koda za potrebe testiranja" },
            { "xxx", "neznana valuta" },
            { "ydd", "jemenski dinar" },
            { "yer", "jemenski rial" },
            { "yud", "stari jugoslovanski dinar" },
            { "yum", "novi jugoslovanski dinar" },
            { "yun", "jugoslovanski konvertibilni dinar" },
            { "zal", "ju\u017enoafri\u0161ki finan\u010dni rand" },
            { "zar", "ju\u017enoafri\u0161ki rand" },
            { "zmk", "zambijska kva\u010da (1968\u20132012)" },
            { "zmw", "zambijska kva\u010da" },
            { "zrn", "zairski novi zaire" },
            { "zrz", "zairski zaire" },
            { "zwd", "zimbabvejski dolar" },
            { "zwl", "zimbabvejski dolar (2009)" },
        };
        return data;
    }
}
